import { INavigationTopBarProps, ITopBarAlertProps, ITopBarTitleProps } from './types';
import * as React from 'react';
/**
 * NavigationTopBar is used to display a top bar in the app frame - mostly to display alerts, but arbitrary content can be placed there too.
 * @example
 * <NavigationTopBar>
 *     <NavigationTopBar.Alert kind="error">
 *       Something went wrong
 *     </NavigationTopBar.Alert>
 * </NavigationTopBar>
 */
export declare const NavigationTopBar: {
    ({ children, className, additionalNodes, id, }: INavigationTopBarProps): React.ReactElement;
    Alert: React.FC<ITopBarAlertProps>;
    Title: React.FC<ITopBarTitleProps>;
};
/**
 * Title component for the NavigationTopBar. Supposed to be placed in the `additionalNodes` prop of the NavigationTopBar.
 * @example
 * <NavigationTopBar additionalNodes={<NavigationTopBar.Title>Example top bar content</NavigationTopBar.Title>}>
 * </NavigationTopBar>
 */
export declare const NavigationTopBarTitle: React.FC<ITopBarTitleProps>;
/**
 * Alert component for the NavigationTopBar.
 * @example
 * <NavigationTopBar>
 *    <NavigationTopBar.Alert kind="error" show={!!error}>
 *     Something went wrong
 *   </NavigationTopBar.Alert>
 * </NavigationTopBar>
 * @example
 * <NavigationTopBar>
 *     <NavigationTopBarAlert
 *      kind="warning"
 *      primaryCta={{ label: 'Save', onClick: () => console.log('Save clicked') }}
 *      secondaryCta={{ label: 'Discard', onClick: () => console.log('Discard clicked') }}
 *      closeButton={{ onClick: () => console.log('Close clicked') }}
 *      show={!hasUnsavedChanges && !hasClosedAlert}
 *      >
 *      You have unsaved changes
 *     </NavigationTopBarAlert>
 * </NavigationTopBar>
 **/
export declare const NavigationTopBarAlert: React.FC<ITopBarAlertProps>;
